@@ -15,10 +15,4 @@ from dsharp.math import mod
 from dsharp.file import rfile
 from dsharp.file import cfile
 from dsharp.file import wfile
-from dsharp.file import dfile
-from dsharp.mouse import mousemove
-from dsharp.mouse import mouseclick
-from dsharp.mouse import mousedrag
-from dsharp.mouse import keypress
-from dsharp.mouse import onpress
-from dsharp.mouse import offpress
\ No newline at end of file
+from dsharp.file import dfile
\ No newline at end of file
